#ifndef KYSEC_NETCTL_LIST_H
#define KYSEC_NETCTL_LIST_H

enum {
    KYLIN_NETCTL_DISABLE = 0, /* 关闭 */
    KYLIN_NETCTL_WLIST,     /* 白名单模式值 */
    KYLIN_NETCTL_BLIST      /* 黑名单模式值 */
};

#ifdef __cplusplus
extern "C" {
#endif

/*
 * 设置网络管控模式
 * 参数： KYLIN_NETCTL_DISABLE 关闭； KYLIN_NETCTL_WLIST 白名单模式； KYLIN_NETCTL_BLIST 黑名单模式
 * 返回值:
 * 		0 : 设置成功
 * 		1 : 当前状态设置成功，但重启后状态会恢复默认状态
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 网络管控状态设置失败
 */
int kylin_netctl_status_set(int mode);

/*
 * 获取当前网络管控模式
 * 参数： 
 * 返回值:
 * 		0 : 网络管控关闭
 * 		1 : 白名单模式
 * 		2 : 黑名单模式
 * 		其他 : 获取失败
 */
int kylin_netctl_status_get();

/*
 * 添加网络管控应用至对应模式下管控名单
 * 参数： mode	KYLIN_NETCTL_WLIST 白名单模式； KYLIN_NETCTL_BLIST 黑名单模式
 * 		 path	应用程序绝对路径
 * 返回值:
 * 		0 : 添加成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 *		-3 : 文件类型不符，仅支持二进制程序
 * 		-4 : 添加至管控列表失败
 * 		-5 : 获取应用基准值失败
 * 		-6 : 设置应用网络管控状态失败
 */
int kylin_netctl_list_add(int mode, const char *path);

/*
 * 从对应模式下管控名单中删除网络管控应用
 * 参数： mode	KYLIN_NETCTL_WLIST 白名单模式； KYLIN_NETCTL_BLIST 黑名单模式
 * 		 path	应用程序绝对路径
 * 返回值:
 * 		0 : 删除成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 从管控列表删除失败
 * 		-4 : 获取应用基准值失败
 * 		-5 : 移除应用网络管控状态失败
 */
int kylin_netctl_list_del(int mode, const char *path);

/*
 * 根据模式获取网络管控包列表数据
 * 参数： mode	KYLIN_NETCTL_WLIST 白名单模式； KYLIN_NETCTL_BLIST 黑名单模式
 * 		 count	返回list大小
 * 返回值:
 * 		NULL : 获取失败或列表为空
 * 		非NULL : list列表，大小为count大小
 */
char **kylin_netctl_pkg_list_get(int mode, int *count);

/*
 * 添加网络管控包至对应模式下管控名单
 * 参数： mode	KYLIN_NETCTL_WLIST 白名单模式； KYLIN_NETCTL_BLIST 黑名单模式
 * 		 path	应用程序绝对路径
 * 返回值:
 * 		0 : 添加成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-4 : 添加至管控列表失败
 * 		-5 : 获取应用基准值失败
 * 		-6 : 设置应用网络管控状态失败
 */
int kylin_netctl_pkg_list_add(int mode, const char *pkg);

/*
 * 从对应模式下管控名单中删除网络管控包
 * 参数： mode	KYLIN_NETCTL_WLIST 白名单模式； KYLIN_NETCTL_BLIST 黑名单模式
 * 		 path	应用程序绝对路径
 * 返回值:
 * 		0 : 删除成功
 * 		-1 : 输入参数无效
 * 		-2 : kysec未启用
 * 		-3 : 从管控列表删除失败
 * 		-4 : 获取应用基准值失败
 * 		-5 : 移除应用网络管控状态失败
 */
int kylin_netctl_pkg_list_del(int mode, const char *pkg);

#ifdef __cplusplus
}
#endif

#endif // WHLIST_DBUS_INTERFACE_H
